.:GetBlogName:.

.:IfInThread:: .:IfRSSEnabled:::. .:IfAtomEnabled:::. :. .:GetStyleSheets:.
.:IfInfiniteScrollEnabled:: .:IfInThread::
:: :.
:. .:ForBlogMetadataIfExists::custom_scripts::
:. .:ForBlogMetadataIfExists::custom_styles:::.
.:IfInThreadAndHasFeeds:: .:IfFeedsEnabled::
.:IfRSSEnabled::RSS:..:IfRSSEnabled:: .:IfAtomEnabled::⋅:: :. :: :..:IfAtomEnabled::ATOM:.
:. :.
.:IfCategories::
.:GetFlattenedBlogCategoriesFromBranches::taxonomy::

{value}

{childs}

::

::
- #{value}
:: ・ :.
.:GetBlogCategoriesTreeFromBranches::taxonomy::
☰

{value}

{childs}
::

::

::
- {value}::{childs}
::

:.
:. .:IfChapters::

CHAPTERS

.:IfBlogMetadataIsTrue::disable_chapters:: ::

.:GetChapters::

::
- {index}. {title}::
::

:.
:.
:. .:IfBlogMetadataIsTrue::disable_archives:: ::
☰

ARCHIVES

.:ForBlogArchives::
- {value}
::・:.

:.